@@ -322,14 +322,14 @@ class BibList(dict):
 
     if verbose:
       print '# %d items to output' %(len(self.ListItems))
-
-    if formato == 'bibtex':  self.export_bibtex(fout)
-    elif formato == 'latex' :  self.export_latex(fout)
-    elif formato == 'html'  :  self.export_html(fout)
-    elif formato == 'xml'   :  self.export_xml(fout)
+    fform = formato.lower()[0]
+    if fform == 'b':  self.export_bibtex(fout)
+    elif fform == 'l' or fform == 't': self.export_latex(fout)
+    elif fform == 'h':  self.export_html(fout)
+    elif fform == 'x':  self.export_xml(fout)
     else:
       fi= helper.openfile(fout,'w')
-      if formato   == 'full'  :   fi.write(str(self))
+      if fform == 'f':   fi.write(str(self))
       else:  fi.write(self.preview().encode(self.encoding))
       helper.closefile(fi)
 
@@ -367,23 +367,22 @@ class BibList(dict):
     fi= helper.openfile(fname,'w');  fi.write(self.to_bibtex(width));  helper.closefile(fi)
 
   ##############################
-  def to_latex(self,style={}):
-    if not self.issorted:
-      self.sort()
+  def to_latex(self,style={}, label = r'\item'):
+    if not self.issorted:  self.sort()
 
     s=''
     for l in self.sortedList:
       if self.keepAbbrevs:
-        bib=bibitem.BibItem(self.get_item(l)) # copy the item to resolve_abbrevs
+        bib= bibitem.BibItem(self.get_item(l)) # copy the item to resolve_abbrevs
         bib.resolve_abbrevs(self.abbrevDict)
         ss= bib.to_latex(style)
       else:
         ss= self.get_item(l).to_latex(style)
-      s+= '%s %s\n' %(r'\item',ss)
+      s+= '%s %s\n' %(label, ss)
     return s
 
       
-  def export_latex(self, fname=None, style={}, head=None,tail=None):
+  def export_latex(self, fname=None, style={}, label = r'\item', head=None,tail=None):
     """
     Export a bibliography (set of items) to a file in latex format:
     """
@@ -396,7 +395,7 @@ class BibList(dict):
 '''
     if tail== None:
       tail= r'\end{enumerate} \end{document}'
-    s= '%s\n%s\n%s\n'%(head, self.to_latex(style=style).encode('latex'), tail)
+    s= '%s\n%s\n%s\n'%(head, self.to_latex(style=style, label = label).encode('latex'), tail)
     fi= helper.openfile(fname,'w');  fi.write(s);  helper.closefile(fi)
 
   ##############################
