@@ -18,15 +18,26 @@ latex.register()
 
 import helper
 
+reg_pages=re.compile(r'\W+')
+
 def process_pages(pages):
   """ Returns a 2-tuple (firstpage,lastpage) from a string"""
-  pp=pages.split('-')
+  pp=reg_pages.split(pages)
   firstpage=pp[0]
   if len(pp)==2:
     lastpage=pp[1]
   else:
     lastpage=''
   return firstpage,lastpage
+# def process_pages(pages):
+#   """ Returns a 2-tuple (firstpage,lastpage) from a string"""
+#   pp=pages.split('-')
+#   firstpage=pp[0]
+#   if len(pp)==2:
+#     lastpage=pp[1]
+#   else:
+#     lastpage=''
+#   return firstpage,lastpage
 
 def bibtexauthor(data):
   """ Returns a list of authors where each author is a list of the form:
